Technical implementation details
================================

.. automodule:: uwacan._core

.. .. currentmodule:: uwacan

.. .. autosummary::
..     :toctree: generated

..     TimeData
..     FrequencyData
..     TimeFrequencyData
..     dB
..     Transit
..     TimeWindow
